<?php

namespace Drupal\datafield\Plugin\DataField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldFormatterInterface;

/**
 * Plugin implementation of the 'number_unformatted' formatter.
 *
 * @FieldFormatter(
 *   id = "number_unformatted",
 *   label = @Translation("Unformatted"),
 *   field_types = {
 *     "decimal",
 *     "numeric",
 *     "float",
 *   }
 * )
 */
class NumericUnformattedFormatter implements DataFieldFormatterInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'thousand_separator' => '',
      'decimal_separator' => '.',
      'scale' => 2,
      'prefix_suffix' => TRUE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements($item, $langcode) {
    return ['#markup' => $item->value];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $form['#settings'];
    $elements['decimal_separator'] = [
      '#type' => 'select',
      '#title' => $this->t('Decimal marker'),
      '#options' => ['.' => $this->t('Decimal point'), ',' => $this->t('Comma')],
      '#default_value' => $settings['decimal_separator'] ?? self::defaultSettings()['decimal_separator'],
    ];
    $elements['scale'] = [
      '#type' => 'number',
      '#title' => $this->t('Scale', [], ['context' => 'decimal places']),
      '#min' => 0,
      '#max' => 10,
      '#default_value' => $settings['scale'] ?? self::defaultSettings()['scale'],
      '#description' => $this->t('The number of digits to the right of the decimal.'),
    ];
    $options = [
      '.' => $this->t('Decimal point'),
      ',' => $this->t('Comma'),
      ' ' => $this->t('Space'),
      chr(8201) => $this->t('Thin space'),
      "'" => $this->t('Apostrophe'),
    ];
    $elements['thousand_separator'] = [
      '#type' => 'select',
      '#title' => $this->t('Thousand marker'),
      '#options' => $options,
      '#empty_option' => $this->t('- Select -'),
      '#default_value' => $settings['thousand_separator'] ?? self::defaultSettings()['thousand_separator'],
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    $summary[] = $this->t('Number format: @format', [
      '@format' => number_format(1234.1234567890,
        $settings['scale'] ?? self::defaultSettings()['scale'],
        $settings['decimal_separator'] ?? self::defaultSettings()['decimal_separator'],
        $settings['thousand_separator'] ?? self::defaultSettings()['thousand_separator'],
      ),
    ]);
    return $summary;
  }

}
